translate.storage.placeables.interfaces

Package translate :: Package storage :: Package placeables :: Module interfaces |
[hide private]
[frames] | no frames]

# Module interfaces

source code

This file contains abstract (semantic) interfaces for placeable implementations.

Classes | [hide private]
| InvisiblePlaceable
| MaskingPlaceable
| ReplacementPlaceable
| SubflowPlaceable
| Delimiter
| PairedDelimiter

Variables | [hide private]
| __package__ = ``'``translate.storage.placeables``'``

Imports: StringElem